function edit_QuantyPath_Callback(hObject, eventdata, handles)
% hObject    handle to edit_QuantyPath (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_QuantyPath as text
%        str2double(get(hObject,'String')) returns contents of edit_QuantyPath as a double


end

